#include <cmath>
#include <cstring>
#include <iostream>
#include <iomanip>
#include <map>
#include <string>
#include <vector>
#include <fstream>
#include <sstream>
#include <cstdlib>

using namespace std;

vector<map<string,map<int,double> > > scores;
vector<map<string,int> > counts;

const int SIDE = 15;
const int COLUMN = 12;

const int NUM_TESTS = 8;
const string key_names[NUM_TESTS] = {
  "test_1a",
  "test_1b",
  "test_2a",
  "test_2b",
  "test_2c",
  "test_3",
  "test_4",
  "all"
};

const int NUM_SCORES = 8;
const string score_names[NUM_SCORES] = {
  "endpoint sensitivity", 
  "endpoint specificity", 
  "midpoint sensitivity", 
  "midpoint specificity", 
  "cluster sensitivity", 
  "cluster specificity", 
  "residue sensitivity", 
  "residue specificity"
};

string get_test (const string &s){
  string t = s.substr(s.find ('=')+1);
  return t.substr(0,t.find ('/'));
}

double get_val (const string &s){
  string t = s.substr (s.find ("=")+1);
  if (t == "nan;") return 0;
  double x = atof (t.substr (0, t.length()-1).c_str());
  if (isnan (x)) cerr << t << endl;
  return x;
}

int main (int argc, char **argv){
  if (argc < 2){
    cerr << "Usage: summarize scores [scores2...]" << endl;
    exit(1);
  }

  scores.resize (argc-1);
  counts.resize (argc-1);

  for (int j = 0; j < argc-1; j++){
    ifstream data (argv[j+1]);
    string s;
    
    while (getline (data, s)){
      istringstream iss(s);
      string ref, test;
      
      iss >> ref >> test;
      test = get_test(ref);
      for (int i = 0; i < NUM_SCORES; i++){
	iss >> s;
	double x = get_val (s);
	scores[j][test][i] += x;
	scores[j]["all"][i] += x;
      }
      counts[j][test]++;
      counts[j]["all"]++;
    }

    data.close();
  }

  for (int m = 0; m < NUM_SCORES; m++){

    cout << endl;
    cout << setw((SIDE+COLUMN*NUM_TESTS+3)/2 + score_names[m].length()/2) << score_names[m] << endl;
    cout << endl;
    cout << setw(SIDE+3) << "";
    for (int i = 0; i < NUM_TESTS; i++)
      cout << setw(COLUMN) << key_names[i];
    cout << endl;
    cout << setw(SIDE+3) << "";
    for (int i = 0; i < NUM_TESTS; i++){
      ostringstream oss;
      oss << "(" << counts[0][key_names[i]] << ")";
      cout << setw(COLUMN) << oss.str();
    }
    cout << endl;
    
    cout << setw(SIDE+3) << "";
    for (int i = 0; i < COLUMN*NUM_TESTS; i++) cout << "_";
    cout << endl;
    
    cout << setw(SIDE+3) << "|" << endl;
    
    for (int k = 0; k < argc-1; k++){
      string name = string (argv[k+1]);
      cout << setw(SIDE) << name.substr(name.find ('.')+1) << "  |";
      for (int j = 0; j < NUM_TESTS; j++){
	cout << setw(COLUMN) << setprecision(2)
	     << setiosflags(ios::fixed | ios::showpoint) 
	     << scores[k][key_names[j]][m] / counts[k][key_names[j]];
      }
      cout << endl;
    }
    cout << endl;
  }
}
